Package superseded
==================


Package superseded
~~~~~~~~~~~~~~~~~~

This package has been superseded. The `dtw-python <https://pypi.org/project/dtw-python>`__ package should used instead.

Please see the project's home page at <https://dynamictimewarping.github.io>.

